tiled.structures.xarray.DatasetStructure
========================================

.. currentmodule:: tiled.structures.xarray

.. autoclass:: DatasetStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DatasetStructure.__init__
      ~DatasetStructure.from_json
   
   

   
   
   